@@ -1,13 +1,10 @@
 import pathlib
-import logging
 
 import yaml
 import pydantic
 
 from conda_store_server import schema
 
-logger = logging.getLogger(__name__)
-
 
 def validate_environment(specification):
     try:
@@ -30,11 +27,9 @@ def discover_environments(paths):
     for path in paths:
         path = pathlib.Path(path).resolve()
         if path.is_file() and is_environment_file(path):
-            logger.debug(f"discoverd environment filename={path}")
             environments.append(path)
         elif path.is_dir():
             for _path in path.glob("*"):
                 if is_environment_file(_path):
-                    logger.debug(f"discoverd environment filename={_path}")
                     environments.append(_path)
     return environments
