@@ -15,7 +15,7 @@ from sqlalchemy import (
     UniqueConstraint,
     ForeignKey,
 )
-from sqlalchemy.orm import sessionmaker, relationship, scoped_session
+from sqlalchemy.orm import sessionmaker, relationship, scoped_session, backref
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy import create_engine
@@ -53,6 +53,10 @@ class Namespace(Base):
     id = Column(Integer, primary_key=True)
     name = Column(String, unique=True)
 
+    environments = relationship("Environment", back_populates="namespace")
+
+    deleted_on = Column(DateTime, default=None)
+
 
 class Specification(Base):
     """The specifiction for a given conda environment"""
@@ -98,8 +102,12 @@ class Build(Base):
     specification_id = Column(Integer, ForeignKey("specification.id"), nullable=False)
     specification = relationship(Specification, back_populates="builds")
 
-    namespace_id = Column(Integer, ForeignKey("namespace.id"), nullable=False)
-    namespace = relationship(Namespace)
+    environment_id = Column(Integer, ForeignKey("environment.id"), nullable=False)
+    environment = relationship(
+        "Environment",
+        backref=backref("builds", cascade="all, delete-orphan"),
+        foreign_keys=[environment_id],
+    )
 
     packages = relationship("CondaPackage", secondary=build_conda_package)
 
@@ -110,7 +118,9 @@ class Build(Base):
     ended_on = Column(DateTime, default=None)
     deleted_on = Column(DateTime, default=None)
 
-    build_artifacts = relationship("BuildArtifact", back_populates="build")
+    build_artifacts = relationship(
+        "BuildArtifact", back_populates="build", cascade="all, delete-orphan"
+    )
 
     def build_path(self, store_directory):
         store_path = os.path.abspath(store_directory)
@@ -223,8 +233,12 @@ class Environment(Base):
 
     name = Column(String, nullable=False)
 
-    build_id = Column(Integer, ForeignKey("build.id"))
-    build = relationship(Build)
+    current_build_id = Column(Integer, ForeignKey("build.id"))
+    current_build = relationship(
+        Build, foreign_keys=[current_build_id], post_update=True
+    )
+
+    deleted_on = Column(DateTime, default=None)
 
 
 class CondaChannel(Base):
@@ -240,8 +254,10 @@ class CondaChannel(Base):
             # nothing to update
             return
 
-        for architecture in repodata:
-            packages = list(repodata[architecture]["packages"].values())
+        for architecture in repodata["architectures"]:
+            packages = list(
+                repodata["architectures"][architecture]["packages"].values()
+            )
 
             existing_architecture_sha256 = {
                 _[0]
@@ -268,6 +284,12 @@ class CondaChannel(Base):
                             timestamp=package.get("timestamp"),
                             version=package["version"],
                             channel_id=self.id,
+                            summary=repodata.get("packages", {})
+                            .get(package["name"], {})
+                            .get("summary"),
+                            description=repodata.get("packages", {})
+                            .get(package["name"], {})
+                            .get("description"),
                         )
                     )
                     existing_architecture_sha256.add(package["sha256"])
@@ -312,6 +334,9 @@ class CondaPackage(Base):
     timestamp = Column(BigInteger, nullable=True)
     version = Column(String, nullable=False)
 
+    summary = Column(String, nullable=True)
+    description = Column(String, nullable=True)
+
     def __repr__(self):
         return f"<CondaPackage (channel={self.channel} name={self.name} version={self.version} sha256={self.sha256})>"
 
