@@ -22,7 +22,9 @@ def ui_create_get_environment():
     conda_store = get_conda_store()
     auth = get_auth()
 
-    orm_namespaces = auth.filter_namespaces(api.list_namespaces(conda_store.db))
+    orm_namespaces = auth.filter_namespaces(
+        api.list_namespaces(conda_store.db, show_soft_deleted=False)
+    )
 
     context = {
         "namespaces": orm_namespaces.all(),
@@ -63,7 +65,9 @@ def ui_list_environments():
     server = get_server()
     auth = get_auth()
 
-    orm_environments = auth.filter_environments(api.list_environments(conda_store.db))
+    orm_environments = auth.filter_environments(
+        api.list_environments(conda_store.db, show_soft_deleted=False)
+    )
 
     context = {
         "environments": orm_environments.all(),
@@ -74,6 +78,23 @@ def ui_list_environments():
     return render_template("home.html", **context)
 
 
+@app_ui.route("/namespace/", methods=["GET"])
+def ui_list_namespaces():
+    conda_store = get_conda_store()
+    auth = get_auth()
+
+    orm_namespaces = auth.filter_namespaces(
+        api.list_namespaces(conda_store.db, show_soft_deleted=False)
+    )
+
+    context = {
+        "namespaces": orm_namespaces.all(),
+        "entity": auth.authenticate_request(),
+    }
+
+    return render_template("namespace.html", **context)
+
+
 @app_ui.route("/environment/<namespace>/<name>/", methods=["GET"])
 def ui_get_environment(namespace, name):
     conda_store = get_conda_store()
@@ -96,10 +117,7 @@ def ui_get_environment(namespace, name):
     context = {
         "environment": environment,
         "entity": auth.authenticate_request(),
-        "environment_builds": api.get_environment_builds(
-            conda_store.db, namespace, name
-        ),
-        "spec": yaml.dump(environment.build.specification.spec),
+        "spec": yaml.dump(environment.current_build.specification.spec),
     }
 
     return render_template("environment.html", **context)
@@ -127,7 +145,7 @@ def ui_edit_environment(namespace, name):
     context = {
         "environment": environment,
         "entity": auth.authenticate_request(),
-        "specification": yaml.dump(environment.build.specification.spec),
+        "specification": yaml.dump(environment.current_build.specification.spec),
         "namespaces": [environment.namespace],
     }
 
@@ -148,7 +166,7 @@ def ui_get_build(build_id):
         )
 
     auth.authorize_request(
-        f"{build.namespace.name}/{build.specification.name}",
+        f"{build.environment.namespace.name}/{build.environment.name}",
         {Permissions.ENVIRONMENT_READ},
         require=True,
     )
@@ -183,7 +201,7 @@ def api_get_build_logs(build_id):
 
     build = api.get_build(conda_store.db, build_id)
     auth.authorize_request(
-        f"{build.namespace.name}/{build.specification.name}",
+        f"{build.environment.namespace.name}/{build.environment.name}",
         {Permissions.ENVIRONMENT_READ},
         require=True,
     )
@@ -198,7 +216,7 @@ def api_get_build_lockfile(build_id):
 
     build = api.get_build(conda_store.db, build_id)
     auth.authorize_request(
-        f"{build.namespace.name}/{build.specification.name}",
+        f"{build.environment.namespace.name}/{build.environment.name}",
         {Permissions.ENVIRONMENT_READ},
         require=True,
     )
@@ -214,7 +232,7 @@ def api_get_build_yaml(build_id):
 
     build = api.get_build(conda_store.db, build_id)
     auth.authorize_request(
-        f"{build.namespace.name}/{build.specification.name}",
+        f"{build.environment.namespace.name}/{build.environment.name}",
         {Permissions.ENVIRONMENT_READ},
         require=True,
     )
@@ -229,7 +247,7 @@ def api_get_build_archive(build_id):
 
     build = api.get_build(conda_store.db, build_id)
     auth.authorize_request(
-        f"{build.namespace.name}/{build.specification.name}",
+        f"{build.environment.namespace.name}/{build.environment.name}",
         {Permissions.ENVIRONMENT_READ},
         require=True,
     )
